@@ -2,14 +2,12 @@ try:
     import urlparse
 except ImportError:
     import urllib.parse as urlparse
-import json
 
 from django import forms
 from django.forms import inlineformset_factory
 from django.utils.translation import gettext_lazy as _
 
-from . import settings
-from .ck_editor.widgets import CkEditorWidget
+from .conf import settings
 from .medium_editor.widgets import MediumEditorWidget
 from .models import (
     Attachment,
@@ -29,11 +27,32 @@ from .models import (
     TextImage,
     Video,
 )
+from .utils import import_class
 
 
 class BaseContentForm(forms.ModelForm):
+    base_content_fields = (
+        "position",
+        "visible",
+        "css_class",
+        "margin_bottom",
+        "padding_top",
+        "padding_bottom",
+        "alternate_color",
+        "background_color",
+    )
+
+    def main_fields(self):
+        excluded_fields = tuple(self.base_content_fields)
+        excluded_fields += getattr(self._meta, "options_fields", ())
+
+        for field in self.fields:
+            if field not in excluded_fields:
+                yield self[field]
+
     class Meta:
-        fields = ("position", "visible", "css_class", "margin_bottom")
+        options_fields = tuple()
+        fields = "__all__"
 
 
 class GalleryForm(BaseContentForm):
@@ -44,7 +63,7 @@ class GalleryForm(BaseContentForm):
             "columns",
             "divided",
             "crop",
-        ) + BaseContentForm.Meta.fields
+        ) + BaseContentForm.base_content_fields
 
 
 class MediumEditorForm(BaseContentForm):
@@ -54,7 +73,7 @@ class MediumEditorForm(BaseContentForm):
             "text",
             "box",
             "width",
-        ) + BaseContentForm.Meta.fields
+        ) + BaseContentForm.base_content_fields
         widgets = {"text": MediumEditorWidget(file_upload_dir="medium_editor_uploads")}
 
 
@@ -66,8 +85,12 @@ class CkEditorForm(BaseContentForm):
             "content_centered",
             "box",
             "width",
-        ) + BaseContentForm.Meta.fields
-        widgets = {"text": CkEditorWidget(file_upload_dir="ck_editor_uploads")}
+        ) + BaseContentForm.base_content_fields
+        widgets = {
+            "text": import_class(settings.XPREZ_CK_EDITOR_CONTENT_WIDGET)(
+                file_upload_dir="ck_editor_uploads"
+            )
+        }
 
 
 class QuoteForm(forms.ModelForm):
@@ -87,7 +110,7 @@ class QuoteContentForm(BaseContentForm):
             "display_two",
             "title",
             "box",
-        ) + BaseContentForm.Meta.fields
+        ) + BaseContentForm.base_content_fields
 
 
 class VideoForm(BaseContentForm):
@@ -119,7 +142,7 @@ class VideoForm(BaseContentForm):
             "poster_image",
             "url",
             "width",
-        ) + BaseContentForm.Meta.fields
+        ) + BaseContentForm.base_content_fields
         widgets = {
             "url": forms.URLInput(attrs={"class": "long"}),
         }
@@ -128,13 +151,13 @@ class VideoForm(BaseContentForm):
 class CodeInputForm(BaseContentForm):
     class Meta:
         model = CodeInput
-        fields = ("code",) + BaseContentForm.Meta.fields
+        fields = ("code",) + BaseContentForm.base_content_fields
 
 
 class NumbersContentForm(BaseContentForm):
     class Meta:
         model = NumbersContent
-        fields = BaseContentForm.Meta.fields
+        fields = BaseContentForm.base_content_fields
 
 
 class NumberForm(forms.ModelForm):
@@ -159,7 +182,7 @@ class FeatureBoxesForm(BaseContentForm):
             "box_1",
             "box_2",
             "box_3",
-        ) + BaseContentForm.Meta.fields
+        ) + BaseContentForm.base_content_fields
         widgets = {
             "box_1": MediumEditorWidget(mode=MediumEditorWidget.FULL_NO_INSERT_PLUGIN),
             "box_2": MediumEditorWidget(mode=MediumEditorWidget.FULL_NO_INSERT_PLUGIN),
@@ -170,13 +193,13 @@ class FeatureBoxesForm(BaseContentForm):
 class CodeTemplateForm(BaseContentForm):
     class Meta:
         model = CodeTemplate
-        fields = ("template_name",) + BaseContentForm.Meta.fields
+        fields = ("template_name",) + BaseContentForm.base_content_fields
 
 
 class DownloadContentForm(BaseContentForm):
     class Meta:
         model = DownloadContent
-        fields = ("title",) + BaseContentForm.Meta.fields
+        fields = ("title",) + BaseContentForm.base_content_fields
         widgets = {"title": forms.TextInput(attrs={"placeholder": "Files"})}
 
 
@@ -187,20 +210,18 @@ class TextImageForm(BaseContentForm):
             "image",
             "text",
             "image_alignment",
-        ) + BaseContentForm.Meta.fields
+        ) + BaseContentForm.base_content_fields
         widgets = {
-            "text": CkEditorWidget(
-                config=settings.XPREZ_CKEDITOR_CONFIG_FULL_NO_INSERT_PLUGIN
-            ),
+            "text": import_class(settings.XPREZ_TEXT_IMAGE_CONTENT_WIDGET)(),
         }
 
 
 class GridBoxesForm(BaseContentForm):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.ckeditor_widget_tpl = CkEditorWidget(
-            config=settings.XPREZ_CKEDITOR_CONFIG_FULL
-        )  # TODO: cleanup
+        self.ckeditor_widget_tpl = import_class(
+            settings.XPREZ_GRID_BOXES_CONTENT_WIDGET
+        )()
 
     class Meta:
         model = GridBoxes
@@ -211,11 +232,12 @@ class GridBoxesForm(BaseContentForm):
             "text_size",
             "padded",
             "content_centered",
-            "edge_images",
+            "image_sizing",
+            "image_max_width",
             "boxes_filled",
             "border",
             "boxes",
-        ) + BaseContentForm.Meta.fields
+        ) + BaseContentForm.base_content_fields
 
 
 AttachmentFormSet = inlineformset_factory(
