@@ -12,14 +12,14 @@ from django.template.loader import get_template
 from django.urls import re_path
 from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import csrf_exempt
-from xprez.utils import random_string
 
-from .. import contents_manager, settings
 from ..ck_editor import parse_text as ckeditor_parse_text
 from ..ck_editor.widgets import CkEditorWidget
+from ..conf import settings
 from ..medium_editor.utils import parse_text as medium_editor_parse_text
 from ..medium_editor.utils import render_text_parsed as medium_editor_render_text_parsed
 from ..medium_editor.widgets import MediumEditorWidget
+from ..utils import random_string
 from .base import AjaxUploadFormsetContent, Content, ContentItem, FormsetContent
 from .fields import TemplatePathField
 
@@ -102,7 +102,6 @@ class CkEditor(CkEditorFileUploadMixin, Content):
     admin_template_name = "xprez/admin/contents/ck_editor.html"
     front_template_name = "xprez/contents/ck_editor.html"
     icon_name = "text_content"
-    verbose_name = "Text Content"
 
     text = models.TextField()
     # css_class = models.CharField(max_length=100, null=True, blank=True)
@@ -112,6 +111,9 @@ class CkEditor(CkEditorFileUploadMixin, Content):
     )
     content_centered = models.BooleanField(default=False)
 
+    class Meta:
+        verbose_name = "Text Content"
+
     class AdminMedia:
         js = CkEditorWidget.Media.js + PHOTOSWIPE_JS
         css = {"all": CkEditorWidget.Media.css["all"] + PHOTOSWIPE_CSS}
@@ -133,7 +135,9 @@ class QuoteContent(FormsetContent):
     admin_template_name = "xprez/admin/contents/quote.html"
     front_template_name = "xprez/contents/quote.html"
     icon_name = "quote"
-    verbose_name = "Quote"
+
+    class Meta:
+        verbose_name = "Quote"
 
     title = models.CharField(max_length=255, null=True, blank=True)
     box = models.BooleanField(default=False)
@@ -170,7 +174,6 @@ class Quote(ContentItem):
 
 
 class Gallery(AjaxUploadFormsetContent):
-
     COLUMNS_CHOICES = (
         (1, "1"),
         (2, "2"),
@@ -185,7 +188,6 @@ class Gallery(AjaxUploadFormsetContent):
     admin_formset_item_template_name = "xprez/admin/contents/gallery/photo.html"
     front_template_name = "xprez/contents/gallery.html"
     icon_name = "gallery"
-    verbose_name = "Gallery / Image"
     formset_factory = "xprez.admin_forms.PhotoFormSet"
 
     width = models.CharField(
@@ -204,6 +206,9 @@ class Gallery(AjaxUploadFormsetContent):
             photo.position = index
             photo.save()
 
+    class Meta:
+        verbose_name = "Gallery / Image"
+
     class FrontMedia:
         js = PHOTOSWIPE_JS
         css = PHOTOSWIPE_CSS
@@ -244,7 +249,6 @@ class Video(Content):
     )
     admin_template_name = "xprez/admin/contents/video.html"
     front_template_name = "xprez/contents/video.html"
-    verbose_name = "Video"
     icon_name = "video"
     form_class = "xprez.admin_forms.VideoForm"
 
@@ -276,7 +280,6 @@ class Video(Content):
 class CodeInput(Content):
     admin_template_name = "xprez/admin/contents/code_input.html"
     front_template_name = "xprez/contents/code_input.html"
-    verbose_name = "Code Input"
     icon_name = "code"
     form_class = "xprez.admin_forms.CodeInputForm"
 
@@ -289,7 +292,6 @@ class CodeInput(Content):
 class NumbersContent(FormsetContent):
     admin_template_name = "xprez/admin/contents/numbers.html"
     front_template_name = "xprez/contents/numbers.html"
-    verbose_name = "Numbers"
     icon_name = "numbers"
     form_class = "xprez.admin_forms.NumbersContentForm"
     formset_factory = "xprez.admin_forms.NumberFormSet"
@@ -300,6 +302,9 @@ class NumbersContent(FormsetContent):
     def show_front(self):
         return self.numbers.all().count()
 
+    class Meta:
+        verbose_name = "Numbers"
+
     class FrontMedia:
         js = (
             "xprez/libs/jquery.waypoints.min.js",
@@ -324,7 +329,6 @@ class Number(ContentItem):
 class FeatureBoxes(Content):
     admin_template_name = "xprez/admin/contents/feature_boxes.html"
     front_template_name = "xprez/contents/feature_boxes.html"
-    verbose_name = "Feature Boxes"
     icon_name = "feature_boxes"
     form_class = "xprez.admin_forms.FeatureBoxesForm"
 
@@ -332,13 +336,15 @@ class FeatureBoxes(Content):
     box_2 = models.TextField(blank=True)
     box_3 = models.TextField(blank=True)
 
+    class Meta:
+        verbose_name = "Feature Boxes"
+
     def show_front(self):
         return bool(self.box_1)
 
 
 class CodeTemplate(Content):
     admin_template_name = "xprez/admin/contents/code_template.html"
-    verbose_name = "Code Template"
     icon_name = "code_template"
     form_class = "xprez.admin_forms.CodeTemplateForm"
 
@@ -370,13 +376,15 @@ class DownloadContent(AjaxUploadFormsetContent):
     front_template_name = "xprez/contents/download.html"
     admin_formset_item_template_name = "xprez/admin/contents/download/attachment.html"
 
-    verbose_name = "Files"
     icon_name = "files"
     form_class = "xprez.admin_forms.DownloadContentForm"
     formset_factory = "xprez.admin_forms.AttachmentFormSet"
 
     title = models.CharField(max_length=255, blank=True)
 
+    class Meta:
+        verbose_name = "Files"
+
     def get_formset_queryset(self):
         return self.attachments.all()
 
@@ -424,7 +432,6 @@ class TextImageBase(Content):
     form_class = "xprez.admin_forms.TextImageForm"
     admin_template_name = "xprez/admin/contents/text_image.html"
     front_template_name = "xprez/contents/text_image.html"
-    verbose_name = "Image + Text"
     icon_name = "text_image"
 
     ALIGNMENT_LEFT = "left"
@@ -446,6 +453,7 @@ class TextImageBase(Content):
         css = {"css": CkEditorWidget.Media.css["all"]}
 
     class Meta:
+        verbose_name = "Image + Text"
         abstract = True
 
     def show_front(self):
@@ -476,7 +484,6 @@ class GridBoxes(CkEditorFileUploadMixin, Content):
     form_class = "xprez.admin_forms.GridBoxesForm"
     admin_template_name = "xprez/admin/contents/grid_boxes/grid_boxes.html"
     front_template_name = "xprez/contents/grid_boxes.html"
-    verbose_name = "Grid Boxes"
     icon_name = "grid_boxes"
 
     MARGIN_CHOICES = (
@@ -504,7 +511,20 @@ class GridBoxes(CkEditorFileUploadMixin, Content):
 
     padded = models.BooleanField(default=True)
     content_centered = models.BooleanField(default=False)
-    edge_images = models.BooleanField(default=False)
+    # edge_images = models.BooleanField(default=False)
+
+    IMAGE_SIZING_CHOICES = (
+        ("fill", "Default"),
+        ("edge", "Edge"),
+        ("icon", "Icon"),
+    )
+    image_sizing = models.CharField(
+        max_length=7, choices=IMAGE_SIZING_CHOICES, default="fill"
+    )
+    image_max_width = models.PositiveSmallIntegerField(
+        default=None, null=True, blank=True
+    )
+
     boxes_filled = models.BooleanField(default=True)
     border = models.BooleanField(default=True)
     boxes = JSONField(null=True)
@@ -530,17 +550,3 @@ class GridBoxes(CkEditorFileUploadMixin, Content):
             if striptags(box_content != ""):
                 return True
         return False
-
-
-contents_manager.register(MediumEditor)
-contents_manager.register(CkEditor)
-contents_manager.register(QuoteContent)
-contents_manager.register(Gallery)
-contents_manager.register(DownloadContent)
-contents_manager.register(Video)
-contents_manager.register(NumbersContent)
-contents_manager.register(FeatureBoxes)
-contents_manager.register(CodeInput)
-contents_manager.register(CodeTemplate)
-contents_manager.register(TextImage)
-contents_manager.register(GridBoxes)
